@@ -1,6 +1,12 @@
 source("incl/start.R")
 library("listenv")
 
+strategies <- c("sequential", "multiprocess", "batchjobs_local")
+
+## CRAN processing times:
+## On Windows 32-bit, don't run these tests
+if (!fullTest && isWin32) strategies <- character(0L)
+
 message("*** Global argument '...' in futures ...")
 
 sum_fcns <- list()
@@ -34,7 +40,7 @@ sum_fcns$D <- function(x, y) {
 }
 
 
-for (strategy in c("sequential", "multiprocess", "batchjobs_local")) {
+for (strategy in strategies) {
   plan(strategy, substitute=FALSE)
 
   for (name in names(sum_fcns)) {
